//
//  Park.swift
//  Park View
//
//  Created by Niv Yahel on 2014-10-30.
//  Copyright (c) 2014 Chris Wagner. All rights reserved.
//

import UIKit
import MapKit

class Park {
  var boundary: [CLLocationCoordinate2D]
  var boundaryPointsCount: NSInteger
  
  var midCoordinate: CLLocationCoordinate2D
  var overlayTopLeftCoordinate: CLLocationCoordinate2D
  var overlayTopRightCoordinate: CLLocationCoordinate2D
  var overlayBottomLeftCoordinate: CLLocationCoordinate2D
  var overlayBottomRightCoordinate: CLLocationCoordinate2D {
    get {
      return CLLocationCoordinate2DMake(overlayBottomLeftCoordinate.latitude,
        overlayTopRightCoordinate.longitude)
    }
  }
  
  var overlayBoundingMapRect: MKMapRect {
    get {
      let topLeft = MKMapPointForCoordinate(overlayTopLeftCoordinate);
      let topRight = MKMapPointForCoordinate(overlayTopRightCoordinate);
      let bottomLeft = MKMapPointForCoordinate(overlayBottomLeftCoordinate);
      
      return MKMapRectMake(topLeft.x,
        topLeft.y,
        fabs(topLeft.x-topRight.x),
        fabs(topLeft.y - bottomLeft.y))
    }
  }
  
  var name: String?
  
  init(filename: String) {
    let filePath = NSBundle.mainBundle().pathForResource(filename, ofType: "plist")
    let properties = NSDictionary(contentsOfFile: filePath!)
    
    let midPoint = CGPointFromString(properties!["midCoord"] as! String)
    midCoordinate = CLLocationCoordinate2DMake(CLLocationDegrees(midPoint.x), CLLocationDegrees(midPoint.y))
    
    let overlayTopLeftPoint = CGPointFromString(properties!["overlayTopLeftCoord"] as! String)
    overlayTopLeftCoordinate = CLLocationCoordinate2DMake(CLLocationDegrees(overlayTopLeftPoint.x),
      CLLocationDegrees(overlayTopLeftPoint.y))
    
    let overlayTopRightPoint = CGPointFromString(properties!["overlayTopRightCoord"] as! String)
    overlayTopRightCoordinate = CLLocationCoordinate2DMake(CLLocationDegrees(overlayTopRightPoint.x),
      CLLocationDegrees(overlayTopRightPoint.y))
    
    let overlayBottomLeftPoint = CGPointFromString(properties!["overlayBottomLeftCoord"] as! String)
    overlayBottomLeftCoordinate = CLLocationCoordinate2DMake(CLLocationDegrees(overlayBottomLeftPoint.x),
      CLLocationDegrees(overlayBottomLeftPoint.y))
    
    let boundaryPoints = properties!["boundary"] as! NSArray
    
    boundaryPointsCount = boundaryPoints.count
    
    boundary = []
    
    for i in 0...boundaryPointsCount-1 {
      let p = CGPointFromString(boundaryPoints[i] as! String)
      boundary += [CLLocationCoordinate2DMake(CLLocationDegrees(p.x), CLLocationDegrees(p.y))]
    }
  }
}